function outputFunctionValues = VLFBatchEvaluation(workingPath, inputVariables, inputVariableValues)
%% initialization
xmlfile = xmlread(workingPath+"parameters.xml");
allLightPathElements = xmlfile.getElementsByTagName('LightPathElement');
numberOfLightPathElements = allLightPathElements.getLength;
%% check input variables
if(length(inputVariables) == length(inputVariableValues)) % valid only when number of variables matches
    % loop over all variables, and change their values in xml
    for i = 1:length(inputVariables) % couting from index 1
        % get target variable information (LightPathElement + Parameter Name)
        targetVariableInfo = strsplit(char(inputVariables(i)),'\');
        targetLightPathElementName = char(targetVariableInfo(1)); % counting from index 1
        targetParameterName = char(targetVariableInfo(2)); % counting from index 1
        % loop to locate target variable inside xml
        for j = 0 : numberOfLightPathElements - 1 % counting from index 0
            % get current LightPathElement
            currentLightPathElement = allLightPathElements.item(j);
            currentLightPathElementName = currentLightPathElement.getAttribute('Name');
            % judge if current LightPathElement name matches with target variable info
            if(currentLightPathElementName == targetLightPathElementName)
                % get all parameters for this LightPathElement
                allParametersOfCurrentElement = currentLightPathElement.getElementsByTagName('Parameter');
                numberOfParameters = allParametersOfCurrentElement.getLength;
                % loop to locate target parameter
                for k = 0:numberOfParameters - 1 % counting from index 0
                    % get current parameter
                    currentParameter = allParametersOfCurrentElement.item(k);
                    currentParameterName = currentParameter.getElementsByTagName('ShortName');
                    % judge if current parameter name matches with target variable info
                    if(currentParameterName.item(0).getTextContent() == targetParameterName)
                        % display initial value as a test
                        currentParameterValue = currentParameter.getElementsByTagName('Value');
                        % change value according to input variables
                        currentParameterValue.item(0).setTextContent(num2str(inputVariableValues(i)));
                    end
                end
            end                      
        end
    end
else % invalid case, display error message
    disp('Invalid case: numbers of variables do not match')
end
% write value back to original xml file
xmlwrite(workingPath+'parameters.xml', xmlfile);
%% execute VLF via batch mode
dos(workingPath+'sample_batch.bat');
%% export output values
xmlResults = xmlread(workingPath+"results.xml");
allResults = xmlResults.getElementsByTagName('Result');
numberOfResults = allResults.getLength;
outputFunctionValues = zeros(1, numberOfResults);
for i = 0:numberOfResults-1 % counting from index 0
    % loop over all possible result values
    currentResult = allResults.item(i);
    currentResultValue = currentResult.getElementsByTagName('Value');
    outputFunctionValues(i+1) = str2double(currentResultValue.item(0).getTextContent());
end
% display of function values
%disp(outputFunctionValues)
